/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import { moduleForComponent, test } from 'ember-qunit';
import hbs from 'htmlbars-inline-precompile';

moduleForComponent('breadcrumb-bar', 'Integration | Component | breadcrumb bar', {
  integration: true
});

test('it renders', function(assert) {
	var breadcrumbs = [{
		text: "Home",
		routeName: "application"
	}, {
		text: "Test"
	}];

	this.set("breadcrumbs", breadcrumbs);

  this.render(hbs`{{breadcrumb-bar breadcrumbs=breadcrumbs}}`);

  assert.equal(this.$('ol.breadcrumb li').length, 2);
  assert.equal(this.$('button.refresh').text(), 'Refresh');
});

test('should trigger refresh action', function(assert) {
	this.on('refresh', function() {
		assert.ok("refresh action");
	});

	this.render(hbs`{{breadcrumb-bar action="refresh"}}`);

	this.$('button.refresh').click();
});